
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2.\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t4\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92.\x00\x00\x00\x00\x00\x00\xcd\xb2\x10\xeeI\x0f\n\xd9F\xcc\x07\xf3\xc0\xc5\xe0<\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b"~\x00c\xf9'\xd5\x177:\xcem\xcb\x96c7u#\xcb\xe6\x16XR\xde\xca.S\xb7\xfd\xd6\xc0\xd4\xcc\\\x16\n}M\xec\xb4\xb3\xc6\xfb8\xf8\xe1\xbe\x82K\xb2\xd2\x93=\xd9I\xb8z\x06\x8a<\x08^\x06nO"
        b'\x88\xf0\xbc\xe4\x92oD,\xd2\xac?\xeb\xa0T3\xf4\x8c\xfc\x02\xfd\xe0\xcc\xf2H\xf5\xf8\xc5\xaa\xa7\x97WU\xe2\x7f\xf3O\xc0e\xb5\\\xa9,o\xccU\x939_ \x9b;\x05\x1dS\xa2<!\xd7\xa1\x83\xe3\xf2\x85\xc8'
        b'\xf3\x05e\xae\xff2\x00\xcar"7\x95\xfc\xe2\n\x8b/)\xd3idT\xb7m\xa3\x86\x17\x8c?x\xe2\xe9\xf16\x97\xe6n\xc1\xf2\xcb%wck\xb0\x81\x0b\xf0{x\'\x05\xc3&\xb3VFY\rh\x15Y\xb6\x07'
        b'\xe7\xa8\x04\x898\x14\x07\xef\x19\xfd5\tR\xfa\x8fX\x82&\xcb\xc2Wp\xf1\xae\x07\xcf;Q\\\xd9\xdbz\x80V\x01\xc3\x7f\x99\xd3\xc8\x83\xa1\xf0\x0eG%\x8e,\xf7\x81\xeb\xd6\x18\x12\xe7s\x85^\xc0\x85K\x1c]\xe8'
        b'\t\xb4\xba>;\xcbA,\xaf\x8f-\x98\xcb\xc7[k\xf1J\xcf\xaf\x8f\xbfl\xa1\xb3C;w\xe2\x9f]\x8dY\xd5\x9d5\xe2&\xb4\x87O\\\xddS\xe2\xf2\xc7\x9f\x8f\xd0\xdb\xe7\xe6?@\xc0\x8c\xae\xc8t\xfe\x92,\xe5'
        b'\xef>e\x19\xb5o\x86\x9bn\xde\xd6Ii\xa0\xb8\xb7\x1e\xcb\xc0\xe8\xdc\x9d\x0e\x81\xa1\xfb\xbdX\xd0q\xe6\xa6Si\xcc\x18/\xb0\xbb\xe4\x12e\xaa>\xa8\xb3\xeb=z\xa9\xd0^\xb6\xe1f\x9cc\x12\x10\\\xcb\x8a\xbb\xda'
        b"<vN\xdf\xe2^a\xbbY\x88F\xd2\xe9>|&\xb1\xa5\x88\x15#\xf5D\xffd\xd9hj\x1f=\x87?H#q\x9f\xfc\xd9\xe2-\x03\x11\x1e)\x0e\x81\xe8\xed\x8a\x9d\xc5'\xd4\x13\xea\x82\x1c\x12`8\x0c\xcb\xa7\x9f"
        b'\x9c\xf9\xc2\x87i^\x84\xb7V\xde\x88\x82\xbf\x81\xb9\xb54\x9b]\xf9\x91;\xd0\xcb\xb4\xafy\x08\xfb\x98\xd7\xb0\xa5\xce\xb3|\x8eS\xe4\xf9\xf6!1\x8cP\xc4<\x89\xa1~\xd4F>\x11+\xfb\xe59\x1eP\x9d\xa6\x99\xf5'
        b'\xe8x!~\x97a\x92+R\xe8\xc9N\xc8\xae\x7f2q\xd0\x9c\xd7\xc04\xc6\xa6\xbf:Q)\x9d_5F~\rv\xdeP\xa2\xe2\xd4\x009\x9b\xc0\xab:\xb0)&\xaa\xf4\xe3#`\xd3\x01\n\x8b;\x93\xd7\xa7\xf2\x17'
        b'#\xe7\xab4\xdd\xf4\x99|\xfd\xc4\xbd\xcf(\x97Say\x05cU\xe2CTY\xfcS\xa6\x0e\xbd\x0edT2\xcf\xd6\x84d>\x01\xc5<;\xf3\xb4pE\xe4\x10\xdbo(\xb37\x14\x16\xfa\xb6\x17\x9f^\xf4t\xe0\x95'
        b'2>;\x1c\xf9|if\x8fv\xb9\n\xf8\xc5\xd3\x03C\xf1\xed%\xf9\x96++\xe9\xe0W\x0b\x84\xe5\xce\x9fuy^\x15\xae\x95\\2%\xf9,\x01\xfc!\x9d\xc3\x87\x84M)\xf8\xb2(\xc9\xd0\xbf^q#\xd1L~'
        b'6{\x0e\x94\x884C\xb4Ifo\x8b\xcf\xb8\x13\x01L\xa0+\x1f`ZK\xbc\xa7\x06\x8c\x11\xaa\xc3\x984\x1c\x8b\xc0\x1d\xc1\xe6\x85c\x01\xcb?\xb4\xeca\x8c\xea3\x0e\xd6\xab\xaeZ+\x1cp1\x05\xf9\x85|\x9bJ'
        b'\xd2W\x03Q\xdc$R\xea/\x8e7@2_\xaaT\xbe\xa4%^\xc8Q,\xd31\xb80Yh\x84\x9eY\x8a\xb0\xb7\xa4\x0e\xefQ\x80\x06\x93\x9d\xa6\x10\x00\x8f"\xb8$\x9f\x15\x04VH\xb7\xace?\xbef%\xbb\xab'
        b'+\xb5IaL\xc9|\xfb\xe0\xb7%d\xe8|W@l\x97p\xe5Y\x9d\x9d\xacw\x1f\xa5r\t\xa6]\x8f\xb6\xf9!\xa6G\x01\xa3y\x11c\xd7\x8c\x9b\x01\xd4\xcb\xe3n\x92\x18t\x02\x15(\xb7~\xb7\xfc|`\x97y'
        b'\xe8\xb7\x18\xc9"\x82\xf8N5\xa7\xe3\x1e3\x01\xdf4\xf7\x01{\xcakYx\x10\xd4\xa2\xe1\xeb\xfa0\x86h\xc0\xfcv-\xfe\xb35.\x9e?sr.)\x1b\\.\xf5\xfec)c\'\xdc\xa2\x91&\xe7\x83\x17-\xad'
        b'IB\xb2\xe0\xb9\xbd9\xbb`G\x81\x06a\xe1\xa2$\xdd\xb4\xdaG\x99*\x11\x81\xbc"7\x01\xa9\x16\xff\xa8\x84kd\xe1\xb2\x11\x91\xe6\xd8\xa1\xbf\xfd\xd5\xf4\xaf\xd0\x12\xe4\xda\xa3I\xca\xc7\xe9\x1b\xe5\xe2\x10\x87\xcf\xe9\xc3'
        b'\x1d\x8bp\x89\xb3\xa8\xf8\xecQ\x8es\xcb\x95\xb3\xeb\xea\xbf\x19#\xf1i\x95\xd4\xe9\xed\x9b\x96\x1b\xc2l)&][^\xdf\xcaH\x9c\xf3\xf2O1\xf2|\xa0\x90V\xae\x0c\r\t\xf7^ \x01\x1c\xa2\x86\xca\xbb\x91\x12\xcc'
        b'\xa7\x84y\xbc\xb34\xf4v\xce\xe7q\xf1\xbe\xef\xc9\x88\xc4\x1f\xcb\x13\xb3\xa2\x1eg\xcd\x07\xde|=Q9 \x15\x7fgN\xfc7\xc8\xe5\xb3w\x18\x03\xe3fe[\tb\xfc\xf2\x18\x82\xd4n\xe3\xa9"\x94f%R\x1a'
        b'\xc3\n4\x97\x06\x90Y\xa2\xc8%\xb4>*\xde\x04\x1dk\xaa\xe2\xfca\xd5ZQ\x83gZ\x9fq\xa7K\x7f\xdd0\xf8^\xdd\xf9\xb5\x98\tvI\x8c\x81,\xbc\xfa8\xb7W\x81\x8c\x17F]4\xfc\xd0L\t\x9f\xbc\xaf'
        b"L\xf2P\xea.3\x83\xe1\x9f\x9b\xb6\xfe\x01=#C\x89\xb4A\xcc'\x81M\x9c\x97\xe8d\xa3\x8b\x17\xe5\xf7dfB3\xc4\xd3Z\xe7\xf1k\xf5YR\xe4\xe8\xcag\x9d\xcc\x91\x08h\x10\xebT\xfa\xa5\xbd\xa0\xf7\xa3\x1f"
        b'gC\x0bU\xea=\xe5\xef\xd5\xbe\xb2_^CR\xf5\xffXt\xd3\xca&\xf1\xa1\x19\x91\xc9\x07Oti\xb86qi\xd4\xf1\xafyR\x02\xf0K\xdd\xd6`o\xaa\xee\x19\xa4\x84\xffn\xf7T\xce.\xc2\xaa\xa6>n_'
        b"E\x942\xb7U\n\x06\xf8/5\xb4\xf7E\x14\x87\x80S\x1e\x14\xa9\xc8\xd4\xcfN\xb1\x07-\xe1\xd9^\xfcx\xe5\x97\xfc\xea\xc4'<\xe6K)\x9e\xd7\xcb}\xaf\x8by\xe4\xed\xe3\xae\xe1J\x08\x00\xad!7\xc5fb\xf8"
        b'F\xcc-f<\xa4\xea\x18\xcem]\x87\xed\x88\xe8\xfe6\xee\xe1\x0c\x98\x9e\xc5\xc7\x7fA6\n\xde\x95\xd0\xb1\xb1M\x00\xd0:\xa95\xa3\x93\xf8\xd7S\x9d\x98\xbde\\\xaf\xa9\xda\x87\xafv\xe4\xdc\xd2\xd3,{\xb1\x06\xa7'
        b"\xdd\n\x87\xcc-\x88=z\xed\x01,\xa6E\xb6\xa2x\xd1\xbe\xdf\xc4\xd4Z\xc6f\x18gk\x9b\x95\xfe\xfbvr\xeb\x7friY\xa0~\xb7\x8e_\xf4U\x0c'#\xb8/\xc6\x95\xea[\xfb?\x0e\x9a\xf7\xac\xcd\x00\\\x97"
        b'>MG\xee\x12,ld\x86A\xe6\xa4\x83\xb3\r\xf5\xd67\xb9\xc3\x7f2\xaa\xb6\xf5\xae\xf5\xe7\xa8KI\xdbH\xc4\xedp\x7f\xa5\xc75)`\x8f\x05j1\xc4\xbd\xf0\xda\x07\x8ff\xaeO\xdb\x9f\xfb\x0bZ\x0ez\x10\xf8'
        b'wY\xe9\x19\xd2<li\xe0\xf0\x81<3\xec~\x81u\x0f\xd6\x17\xb9K\x18.\xde9\xa4\xb9\x0c\x8c%\xe3\xb7Y1\t\x93\xbf\xfdd\xe6!G1u\xe1U~h1\x11\xbd\xde\x13\x8b\xee\xdb\nF<\xb6\x1e]\xa6'
        b"\x86[\x91\xfdQ\xb6\xba\x9fZ#v m_\xaf`\xa0h\x15\xe0\x8b<rY4\xab\x84\xe0}\xbe\xf7\xf7'\x8dr7J\xfdJ\x82\x84M\x93mz\xe1\xa8\xe0<\x8c0\xf0\x1f\x04|\x91\x13\xc3o\x0c\xdfpC|"
        b"9q'\x8f$+\x0f\xf4:\x85&\xcc\xba\x14\xc6\x1c{b\xd95]\x0b\xa7.\x9bG\xf1~\x12\xe1\xda\xae\xb5\x1eG\x06\x84\xd2&a\xbaU\xd4\x04\xacg\x8d\x9e\x81\x0e\xbe\xae\xd3\x05|\xb21\xee\xf6\xae(\xe0^\xe7"
        b'\xe9\x80\xf5k\x83\x06\xdfZP\xdbG\xda\x835|\x14\xe3\x06eZvpx\x15\x00\xea.\xeb\xe1N\xa0\xb2o_\x9cm\xda/\x10\xd6N\x15\xef\xa8(\xbdQ|4\xe1\xd2A\x15\xc0\x08\x10L\x04\xd1>\x8b\x99\x85\x00'
        b'\xf5\xbf*R\xc3"\xac\x89\xf62U#\xea]\xa2\xc2\xbd\x7f\xdb\x91\x12\'\x17\x94\xad\x0b\xd4\xc9\xa1\xdd\xcf\x06h\xef\xce\xa3\xb8\x9b\x92\x96L\xb5\xb3\xd7k\x88\x97\xee\x9f\xc2\xf98;T\x1c\xdf\xd8o7\xc3\x16\xe1\x80\x83'
        b'R\x9c!^\x12V&\x82\xa5^{/\x91\x90\x1b$_ o\xfd\x1d~\xa03p\xe4\xee\xd0\x8c(\x0b"\x83\xf3\x98q\x96\xae\xb0\xd8q\xe6\x19\xffu\xf8\x84\x10\x02\x83\x0f$\xa0\x8a\xeaO\xc5^\xbfs\xa4\x00&U'
        b'\xad\xf91\x02\xea\xa6\xa6o\xfe\x9c\xfc\xd6\x03\x1e\xdb\xee-\x8di\x00\x9e\x97\x8b@E\x95\xb1e\xf6\x9b%\x0f\xc3e1\xe9F)\xf2\xc6\x91u$Z\x9b\xec\x1a\x03LD\xce\xa3\x9cf,\x8c\x87\x04q(\xa3\x9e\x1b\xcb'
        b'\xc9\xe1\n\xe0Q!vC\xbf.\xcaW\x1fp\xdf5C\x04\xa2\x8e\x8d\xe2\xba\x92\xf2\xc1\xfb\xf7\xfbZ\x89\xc7\xad\x8c\xf4\xf9e\xd1\xe4\xf6\xcdrX\x1b\x84\xac\xa5\x9f"\x98=hH\x00\xb6\x1e;vm\xf2\xbb\x10U\xbf'
        b"\xa1\xf5\x1f\x8d\x1b3w\t\xe8d\xf1?ToYT\xf0F\xf9R\xf6\x89\xba\xaa\x93'\xc91\xd7\x01Yo{\xd2\xd5@\xa4\x89\x03 \xbd\x03\xcb\xc8\xa2$X}\xdb#\xdc5+vQ\r5\x04=\xebJf)\xb4"
        b"\x17M\xd2\x99\x99\x88\x9dah\xab.\xd2\x02\xed\xc0\xb1g\x96\x1fw\xbb\xb3,\x98\xaem\xf8?\x9f\x13t\xc0\x8ae\xc4\xc4\x9e\x8d'\xb7\xffU\xbb\xa3K\xa6\xe1\xd6\x9a\xdfr\x9d\xe7k\xb4\xff\x01\x04\xf2\x16\xf3x4&"
        b'\x00\xfc\x1eH\xb2\x8e\xc1\x02\x9e\xf3\x96\xc5\x83^\x8f\xdb.\xc1\x99;\xa24@bH\x93#\xa1\x19N**\x05\xf3\x90B\xe0!\xc6k\x80\xaa?\xe4\xe3\x97M\x1d\xc2\xb5\x0f;(M`N&\xbdz|\xea\xe1O\x08'
        b'\x95\xf3\xb6!\xff\x1d<\x15\xb0K\xaem\x04\xd6\xe8H\xe6 \xaa#\xe5&V\xef\x1b\x1b\x01\x95\xb9\x90?"5\xd9\xc6D\x13H=\xfd\xa0\x85\x06\xdd\xf9\xadK\xeccF\xcd\x12\xecz\xe0\xbdC\x91\xeaR\x06V;\xa9'
        b'Q\xb5\xb1U\xcb\xe6\x91\xc4\x9bm\x04\xf71Y\xa9}\xb4\x99Q\xf0\xdd\xb9\x06\x06>\xe9n\xcf\xcf}u&\x12\xbd\xfeN\xb3l\x1f\xa9\xca<t\xd8\tU\xd6d\xa9k\xb6\xb68\xec\xe4]\xd7\x06TY\xfa\\\xf4g'
        b'\x83\x05\xba\xe21n\xa3|c\xbc\xb0,\xd8V\\8\xeaL\xe0)\x9a\xd4h\xb1(>~\xf7\xe3Wc7\xb5\r\xbd\t\x14\xbcx\x02\xca\xde@\x8cT\x13\xaeV\xcaT6~\xf8\xc4\x95\x94\xc6O\x9d\xf0t\xa3e\xe0'
        b'5zJA<\xed\x8c\x85\xf0z\xc4\xa8\x1e\xee\xd4iu\x0b\xbf\xe9\x85|\x83\xd6\xd4\x0e\x8c\xc3\xd2\xeb\n$\x1b^\xec\xb5\xf1l\xe8Q\xc72z<?\xe4\xfe\xf2\xa4\xd6\xde\x1d\xb4_R\x18@\xe1\xe1;\xcdn<\xc7'
        b'\x87x\x94k\x12N\xdd2\x9f\x9e\xd4\x0b\xdf\xdb\xba$\x86\x1a\x9bo#\x19\x80\xba\x03i\x9a\xc1\x01I\xc2\x03\xd5\x99\x9d\x83\xd8lB|o\\\x9e/\xa1\t\xc3\xbf11_\\\xdc\xb7u\x96(\xec\xa1_u\x1c,Q'
        b'3]\x0b\xb5\x95\x88\x18\xc52\xec\xea\x94[\xf7\xeb\xf2\x13\xa3\x9e\xce\x8fr\x0cwmk\x0eh\xd5\xa1x\xd2?n@\xea\xa2uG\x81\x14\xd2\xed8\\#g\x07\x7fmfJ\xadO\xed\x96*\xd31\x16\x0f\xf2\x85\xe4'
        b'&y\xbb\xcc^{\xe9\x06q#\xb8\xf6\xfd\xe9nt\x01I\xb6<u\x86\x00\xb1\xcb\xfc\xefSexa\x92\x9a\xe1\x1cd=\x01\x898,F\x02c{\x88|\xe5^\xb4Y30&\xcf\xfaxD<\xa7.eY/'
        b"\x85\x92\xb7\xf4k\xa8\xdbET\x8c.\xc9\x1d\xaa\x88\x83\x98V\xbfya&\xd8\xfe\xb3'\r?\xd2\xf1W\x8a\x8f\x9c\x89\xc4e\xb0\x06/\xa4#\xe5\x9e\x1c\x81\x13\x16\x0f\xc7O\xd9&\x05\xf8\xd1hYY\xb1\xf1,k\x8a"
        b'\xecVjITM\xd7\xf8e\xe2z\xffy`)\xe3\x07\xe9\xeb\xbfTO3\xf4#(L\xeb\x8a\xb5V\xa2\x19\xbb\xf7\xa0\xe2\x8c\xa4\xc7\xf6\xae\xdc\xed\xba\xf0\x16k\xad?"\xba5)\x8a\xfck\x0f4Nk\x8dud'
        b'\x9d:\xf9f*\xd3\xae\xd1\xad\xde\x82\x8a\x91\x06UQC\x9e\xa1\xf3\xca\x13/\xdbo\xc4\x13x\xec!M\x1fY\xb6\x0f[G\xaeK({TF\x00\x1d\xd6\xde"S\xad\xf5\xc8\xb8n~\x1b\x83\r\x9f\xd5\xfeh\x87:'
        b'\xde\xc3\xb5\xe7\x91\xac\x04G\xd3\xcf\xcd\x1e\xaf\xd5\x88V\xb0\xe8\x82[\xe0o\xb9tTD\x08\x93\x9c%\x81k\x9c\xfb,J\xfa\xff\xe0\x96\x03\x96\xf9\x15?+\x9d\xfaT\xa8~^_\xe2\xe3\x02\xd7}\xd5\xfdi\xc1\xe7\xd3'
        b'"\x14\xe9\x9c\xaa\x10Sp\xb8\xfd\x97\xd8\x83\x14\xbd\x1d\xc5a\xb6\x12\x1cM\xb20\xfc\r\xde\xc2E\xfb`Sq\xb8\xc7\x15[\xd7\xe3\xfa\xc7NF\xc3\xf2kQyJ\xa9\xbc\x82q\x01\xdb\xd45F\xb9\xd5\xac\xc4\xc8\xb6'
        b"\x8c\x0f`\x7f\xd9/\x90\xe6\x03c\x1aU\x82\x0e\xbc\xa0Y`\x9d\r\xa54?\xbc\xe8\x84 \x93gR\x85\xbe\xf5\x8b\xa2\xb9\xb9Q\xba\xc3\x1fc\xcc\x00\xc0\x8e\xed\xc8\xc8\xe3!f\x8e\xb8h\x05\xa9\xabD\xa3\xc1`'4"
        b'\x18\x95En\xf4\x13\xea\x15\xaa\xd2\xf7\xd4\xe8mv\x82"\xf6\xe3.Q&|@:\xe4A\x8f"\xb0l"\n\x0f+\x98%\x88\xf7\x88\x0f\xbd\xe4\xc1\xd6\x9e\x85\x16\x82M\x7fU\x9d\xa6\x0b\xa6\x1f\x07\x03,7\x05\xc5\r'
        b'\x97\xb6\x067\xaf\xe8md\xad\xd3\x0f\x80\x07-\xb2me\x93\xc8U)}\x0bFi\xf0\xb6\x0f\x84P\xa8\x9f\x10\x1dwM\xde\x87\xdf\xe1\xe0\xe9v\xb3\xf6\x0c\xb2\xc0J\xce\x197D\xfey\xc2\x1e\x0c\xe2%\xd2\xf3B\xca'
        b'\xfc\x08k-\x04?\xa6U\xd1B\xd6])\x19\x8fk\x9cs\xe8f\xb5\xf9\xaf\x9d0\xad\x0cN\x96\xd6\xb2\x1bonC\x94\x1eP\xb8\xfd\xa0\x14m\xeb\xbd\x04\x88!o\x12\x0e,Z\xceC\xda\x9d\xdc\x87\xc1Rt\x8c\xab'
        b"\xb1Z\xdc\xfee\x8c\xdc\xcd\xd2\x87u\x02+\xb73t\xf9_\xb5\x8d\x94\\\xcd'\x9c\x98t-\xde\x8d\xccSQXN\xbbW\x93\x15\x17aF\x96\xff\x05B\xbe\xf8\xec\xdc*\x03\xeb\x84\x03W\x9eDyA\xc5U9 "
        b'\x9e\xe7t\x1b9\xfbm\rV\xff\xbb\xf0Nb\xbb\x1e\xc91\x9dB\xe1]h#,{\xec\x1b\xdd\xfe\x0f\x86ox\xb1\xc9\xb3\xd7R\xad\x00\xa5\xc6\xdf<\x92\x90k\xcf\x1f\xbb\x9a\x8c(8\xca\x1f+\xb3\x06I\xbf[m'
        b'Zg\xd6W*\xd8\xbf\x8e\xe8w/\x91\x91\xb9\xb0kD\xee\x1f\t\xc8\x18\xf2\xb4\xbe\xafBW\xdf\xf0i\xb8\xe9=5c\x18\xbb\x87@\x92A\xb3\xa4E\x89[\xe5\x8e}\x97\xc1N\x7f\xafl7\xbdui\x03\x1d\xea\xe2'
        b'N\x03;\xbfZ\n~\xb7_9!A\xa1\x9e.\xfd\x0f?!\xd8\x1e\xf5\x0e\xdeC@\xedxv\x1d\x9a\xedP+\x8a\x9bl#\x87eb\xd4\xf3L\x9d\xb7\xa0P0=:V\xc7\xeek\xc4*A\xe1\x11\xa6\xe9\x1e\xde'
        b"\\\x94B\xb5W~u\xe6\xf8\x1a\x0bs\xae\xd8P&\x8de\xa3\xd4b\x8fM\x7fD\xfb\xa17\xde\x01\xa6I_-\xe2{\x0e\xd3\xc6^T\xc3&\x9a*\x0cCE\xdfm*C\xf4\xb7'\x95\xed\x87\x92\x8e\x1a\x94\xb7\x8d"
        b'v\x15I\x0b\xc1ZQ\xb2%\xfc_*\xedt\xe9\xf6\x99d\x80\x88ck\x98\xe0\\i\xb4\x97xK\x11b\xe9\x87(x\xfbN\xbfJ\xc5\xa2\x8c{\x81\xf9cU\xb3\x04\x1b\xed\xb8\x9c\x01rZ\xb1\xfc&vg}\xe6'
        b'\x12\x1ezZ\xd7\xa0c\xf7P\x13\xf0\x7f\xb3\x96\x1c(\x1dv\xb3?\xb3\x88\x9b\x1f\xd0%\x0bq\xfe\xcd\x85\xe3Iw\x00\x9d\xe0\x10C\x1c}5!\xf5i\xba%T\x18\xe97\xd6\x9b3?\x9e\xc14\x85P\xbc{\xca8'
        b"\xc2\xf4\xd7\xc9\xc2\xf5,\xf0H}\x10.\xa9\xecl.\xa9\x9dF{Vm\xd8\xc0\x12\x9b\x15\x9a\xe7\xcf\xa9\xca\xa10\x81\x99\xd0\xdf\x82^\xa7\xe1\xf9n\xe0'\x12\xbd\x14\x97s\xd7\xa8\xb2\x8c\xac\x07\x84\xa1p9\x1e\x95\x8e"
        b'\xf3\x19\xf5\x8b\xafY_\r\xa401\xd0w\xdd\x8f\xa8!\xbd\x9b\x99\xeb\xe0\xd2\\V\xca\xeb\xc5\x14LL\x87e\xdc/F$\x0e\xb8\x93\x87hk\x85E\xd5Z\x8c\xe4&\x9c\x19\x07\x16\x99:\x11\x97\xe9\xa9\xc3\x1fl\xf6'
        b'\xe4\xb1\xaf\x83\xd5\xd7\xcdP\x1f \xcf}\xef-2\xe6\x16/\xb0nt\xfa\xd4\xf8f`\xe1\xddGH;KS\x18\xa0!\xecn\xf3`\x19s\xde\xf7\xa7{\x19eIU\x9d4\xfe\x8d\xa03\xb5J\xccmeLMm'
        b'\x07)\xe8\x19\xb64\xbb\x1d\xab\x84%\xeb\xe1\xaf\xf3\xdc\xbb\xf5\xdf\xb3)\xc5\t\x86\x9b\x88 T\xacM\xcf\xd8L\xf5\xc0b6G\xc6\x15\x1c\xce\xec\xc0\x1d~\xdc\xe3\x14\xc7\x1ba\xda"\xdbV\x05$7]\x03i\x12J'
        b'\x86\t5c\x9c\t\x04\x97dO-s!\x1bN"\x849\xf4\xc4\xd2\x0b\xd9\xb3N\x95\x8dLr\xc6y\xbf>\xda\xa0\x96\xad\x8dS[\x1b\xd7\xbf|\xa5\xee\xed\xf5\r\xb0]\x87\xd9\xdeI\xe8!*T\xa4)mq\xd5'
        b'_7\xe8@1C\xc9~\xd86\xbc\x9e\xe7\xa9\x8ck\x90\xf6g\x03\xd2jP\r\x93\xe6G\xd943Y\xde\xe9\x18\xb8\xc2rR\xb6C\x96\xf1\xba`\x101L\xfe\xab{)\xd1\xf2\xce+\x81e\xe9\xf7\x8f*\r\x06\x08'
        b'sC}2\xb2\x9d!\x06Sll\x14\xe2\xad\xf3\xad\x86\xffWy\xf3\xe7\xab\x9b+\xaa\x98\xb3?\x9d<q\x08Q\xa7\xe5U\x13d\xc3Oh\xb3\x8a\xcc\xfa\x0c\xc1y\x97<?\x1f\xbaN<\xc3\xddUR]\x97\x0f\t'
        b'\x88\xdc\x80\x81@v\x83\xa6\x18?M\xb0\xeb\xa7\x06\xa5\xaf\xa7Bv\x029\xc9\x9c<;&)~\xd9\xf0Z\x02\xf8$\xec\\\xfa=\xc2n\xaf(\xf7\x81\x1c\xc3\x15\x8eP\x81\xe8w2\x08z\xea\x19\xef\xd5I\x9d\xec\x00'
        b"\xb4h'\x9a\xab(\xd0e\xc8\xca\xf2\xd4I{\x85\xf1\x07\xc4\xb6\x02\x03=\xe7\xb9^R.\xb5\xe24RT\x9f\x1b\x84c1\xde\xd9\xe0rn\x82X\xb0\xab\x17\xf7\xfe\xb6\xe8\xf6%]\x04\x1c\xb7\xe5`\xdf3\xbaJ\x88"
        b"h\x97\x95b-\xefqT\x93\xba\xac\xec\x88\x98\xc6\x10G(\xa92\x88\xe0\xaf\xb8\xb6f\x88\xf9\x94,#\xbd\xfa\xd0\x9f\xe1`\xa6\x98+\x970\xcd_\xd5\x9e\xf3\xe9\xd0\xc3$P\xa4\xd27\xe3\x0bE\x01\xb8'\x1bK\xae"
        b"\xca\xcf\x8b\xee\x11\x0c\xbft0W\xf0\\=#>\xdbI\xcc\xba\x9a%\x18`\x9bb0\n\xb0{t\x9d\x92O\x06aq?\xde\xed\x88K?\xa5c\xce\xe3\xe7\xfb\x85S\x92\xaf\xdd\xb3\xeb\x9d\xec'\xb71\xf2\x07mG"
        b'\x87\xd0I)9\xea>\xaa8\xe7\x8d\xcf~1\x13mc\xd1~|i\xef\x88-\xee\x95aH\x91\xfd\xde\xa1\xcb\xd3\x85\x196C\xf1\x1c\xf9\x91y.Lw\xde\xdaZ`\xc3\xa1\x9fg\x07\x1eru7\x91\xe1i\x1bq'
        b'M\x18\xa9\xf1!\\@\x8fa\xeb\xcb\x1f\xcc\xfc\x12w\xbd\x91\xc8[w\xaatN"8\x8a\x07PEK\xa5\x12\xd0G\x95~g\xf2\x81\x9cW\x98\x80dtb/z\r\x8e\xf4=D\x89^\xba\xb4"\xee\xd0KP\r'
        b'\xf8\x9b$wU\x8a\xe0\x85u\xdfG\xb8\xf7dl\x86?0e\xfe\x8dY\xe8*FK2\xa8\xbd\xfb\xd2\xf8\xb0\xfe&\x838\x93\x07\xc1\x1a66.\x8d\xca\xa4\x99NH\xf4\xe6l\xf0\x1b\xee\xe0\x8c\xab\xa7\xa4(\xf5\x87'
        b'\x0b\x01t\xfe\xa1\xf1\xc9\xd4\xe8y\xeb\xd4\x95\x1f-:\xe5B\x7f\xa7\x15\x14\xad\x80\xea\xa0\xbc\xf4\xd9s\xd4j\xf6RO\xf9\x07c\xc2\xa2p~}\xa1\xb5\x1ee\xaa\x19Rt\xfc*O\x03u\xdb\x84\xd2S*h\xb0\xfd'
        b'm~8\x99\x07\xea\x84{\x8f\xd0\x04\xec\x8c;\x04?@h\xc2\x02\x01m\xf8\xe7\xddOBC\\H\x9fF\x90\xe0.\xd5?\xb0\xfaQ*_\xa2V\x9c\x8eP\xab\xd5e\x9f!\xe0\x05\x93\xae\xbaT\xeb8\x91pq\x94'
        b'\x8b3D1\xa25\xa8e\xba\x15\xd8\xe0x\xad\xc3\x1fU\xd8\xef\x03g[\x0b\xe5\xb6\xc0\xff\xd6\x19\xea\xb0`_6E\xd6+F\xcc\xb1}5\xaaU\xfc\xe6\xb9S\x12\xed\xf7\xae\xf9\xec\x90\xcb\xe3\n\x15\xd8-\xafV\x05'
        b'\xca\\\xf8oW\xc9Z\xb4\x1e\x8br\x8d\xee\x9bM\xeaY\xe71\x1f\x05\x84\xee\xe5\x84\xa2\xfb\x88\xd5\x86\xf1\xfc\x1e\x1d\x14U>\xc9\xd2\x05?\xab+\xcbX\xc3C`\xc1\xf9\xed\x8f\x83\x8ez\x0fl\xde\xf3\xd8\xe3RnH'
        b"\x90o\x88\r\x7fg\xe4U\x13'>k\x97\xcb\n\xfa\x8d\x7f*U\x98]\xa6V\tKL>g/X\xe6\xd4\x8a\x16\xfaq\xbe\xb7q\x95z\xe1\xcf\xa67\xc3Jj\xe3Cd\x01\xb7jy\x8c\xbf\xb33cyl\x9c"
        b'\xd5z\x05\x1f\xea\xc2\xfdm\xd3Yt\xf0L\xe1@m\xafy\xac\x1c_`\xb38\xf5]\x96\xd0\x8c\xa4\x13\xaa\x14\xbe\xdc\xf5\xc7\x86)9{\\\xc5\xc6\xd4|&\xbe\xd9\xe8f\xff\xb5\xb4\xfd\xe8\x15^Q\x9e\xe3\x04%M'
        b"$4.\xa2\x10\xd4\xae\xd0\xe7\xde\xa0\xe6\xef\xf4\xe2\xb4V\x99LP\xfe\xe8\xfb}\xbb)\xa1\xe6\xa0\xdbKR\xe9\xcf|\xa6\xf94\x83FF\r\xef\xcck\xec\x90\x9b\xdc\x17\x8dI\xd5y\xe96\x00'\xa79\x04\xd8\xd9\x99"
        b'\x86\x80\xe2d\x1b3\x93ucU\xd8QCC\xec\xde\xf2\xe1u\xb8@Z\x7f\xd6\xf7\xeb\x95.\x1b_\xb1\x13\xeb7S\xbc\xb1$kh#_~\xcd\x02\xbf\xc5b\xa7lM\x95\xdc\xb7 e\x8c\xf7\x8c\x99\xd3\x02ii'
        b"\x17\x12\t?\xddg\x8br\xd4\xde\xe0\xc7Y\xf7R1\x05Bn'\x9b~\x1e\xd9\xbeX\xf0\x97\x1f\xe6\xc0\x99\x9b:\x07]\x95U0\xe4\xbf\x15\xae\xac&\xc2K\xe26i}\x11\xc8\xce\x9f\x13\xa3\xe4\xd9\xc8\xfc\\W\xb5"
        b'\t\xa8X"\x1e\x0f\x98\xe5\x9c\xf1\x8f` *f4\x85\x1e\x0c\xff\x92\xddg\xb7\xd6Yt\xda\x08b\xcfC#Gy9\xbe\xcb/{\xc5f\x83|\x9a]\xc3<\x8fxZ\xa2\xa8oz\xc8\x9d,\x01\x81\x08\xbf\x8c\xfa'
        b'\xe9\xf3\x99\xe8S\xb7\xd2\x0e5\x06\r\xf0\xc3\x93?\x86\xb8\xd3\xedHd\x05"\xc3\x03<`\xb7\xa8\x82Kx\x1a,yC\x1a\xcbi\x17\x006\x14\xb3\xe4\xea\xc5\x00\xa8\xa2\xad9n\xf1\xff4\xc4\x02\xaar\xb7c\xf5\xf1'
        b'S\x1d\xc82\x0f\xf8\x8b\x08"\x1bW^f.\x95\xb2\x9a\xf7\x14\x8e\xa9\x80\x96\x9f\xbd\xda\xb1\xe9\x11\xc2\xccX6Q\xbe\x8d\x81\x82\xb5\xf0\xc4\x0f\x8d5\x18\xc2\x9d\x87\xfa\xad\xf8\xf6FI\xe4\xd3\x99e(\xdb\xa3|\xdev'
        b'*\x99\xee8,q5N+\xd2S\xc6\x99\xd7B/\xc88\x8b]\xc7>k\x0f\xfa`5\xa5\xa9Y\x94\xd8\t\x9ei\xde\x029\x0eO\xcc\xe8\x9a\xf0\xf1\xcd\x9c\x01,\xef\xd2Y\x8c\x03\x94\xb6\x05\xb7\xad\xb2\x986\xd1d'
        b'\xeb\xbb\xee\x87(\xf5\x0b$\xc0o_\\h\xa7!\x1d\xef\x13\x9fVx\xcc\xcb\x1d\xf7lN;\xaa]_\xd4\xa7\x84\xb8\xe7P\xb7}\xdcD\xef\xf5\x96\x15\x8f)#\xfd\xf3\x0f\xdb\xfc\xc8\xafB\x1e\x17F\xa5V\x82\xfb\x81'
        b'\xbe\x9eR9z\x01(D9Z\\\xac\x93\xa3\xd5\xc6\xee\x1a\xb3\x93qZVf\x15\x9d2\xbfF+\x03\x04\xfb\xd2\xaf\x9f0\xde\xe9_\xe5\xf6/\x8b\x8c\x0e\x7f\xec\x13\xe2\xd3\x9a\x16R\xad\xac\x08\xdb\x98\x8ebO\x10\xda'
        b'\xb7\xea\xf2\xe8\x82\xb7z|\xed\x0f\xdcs\xc0C$:\xc2Lpl*\x94h\xbao\xbeR\xeb\xbe\x85\xf3\xfc\xe6\xd4m\x966\xf22\xec\xe9\xd6\x884;5\xfdU-\x8d\xc0\x89?\x0c_;L\xd3<q\x0ct\xd8\x1d'
        b"p\xa8\xff\xc2q\xb5pn\xa5\x86_G\xecV>\x8e'\x08\xc7\xea\x903\x1aY,\x9e{:\x9f\x91\x99\x953\xf4\xd28\xb0\xad\xb6\xb0\xe7\xb4\x0e\xe1%\xe4amS\r\x91\x02-J\xe7?\xa1V\x89x\xbd\xf8\x1cl"
        b'\x85\xe8I\x0f}\xe1\xcf\x04M\xc0\xd9\xad\x88\x12\xea9\xb5M=\xc1\x14<\xf1\xc0@]`\x00\x1f\xf9\x97\xb7h\xf5\xa2\x98\xbd\x0f(d\xde0\xee\xfb\xd3\x11a\xd6s5.\xaa\x8co\x85\x8e!E\xb8\x98\xed\x0fc\x82'
        b"\x1e\xc1!)b\x02\xfe\x85x\xa4\xd1\xd7f\xbe\xbd\x90`\xb1\xb2#\xa1\xbb\x12\xfe\xb7y\xb8\xff\x0el\x0e\x84a\xdek\xbb\xe4\xb5u\xb0\x89\xe8'\x94WG>\xc2\xa8r\xf6\xc1\x1by\xf1s\x15}\xb4\xb1\xb2\xf4\x19z"
        b'\x12\x9a\xab\xf9\\\xa4q\xc5gXF\x05?h\x96p3\x17\xb0Tv\xfb\xb2*\x86\x81\xf3\xd1H\x04\xd3\xcb\xa1"^\x04(YrE:\xd3R-\xf9\xf4_\xa5DG\\\x00#\xa1g5\xd2o\xda\x1b\x99&CN'
        b'\xc5\x03\x97\xe2\xf2m\xe1\xf6;h\x86\xfaS\xd2\xc4lCk\x1e\x03\xd8\xee\x96Y\xbf\x82]qdp\x8f\x8c\xd8^\xaa\x1d\xc5\x19\xd5\x94\xf6PT\xe5\xfb%\x86\xceGI\x8f\xe4\xef@\x8d\xb9\xf9r9N\x03\x88\xac\xc9'
        b'\x94\x12\xa8\x8d\xf2\xd0b\xea\xae\xbb\xec\xc5\x06h\x03_\x91\xc5\xcb\xd1\xc60Bx\\b4X<H\x84\xfa\xfc\x83ZhQ\xdf\x83w\xbf\x87\xaf\x00\x97\xb2{\xacv\x05\x1c\x083I|1LfC>\xd9\xa3b+'
        b'U?\xfa\xa1\xeaj\xd7\xa5w1Mh\xb9K\x7f\xdb\x90\xafr%!\xbeX\x88q\x8e\xfe\xc2\ndA\xd7\xa8\xcb\xe4\xe3/\xd4C{l\x88\x0b\xa5\xcb\x06\x8a\xa7\x83\xea\xe2\r\x97\xe2i\xe1\tk\x16\x18a7\xa7\xce'
        b'\x08\x8b\xabA\x90\xc8\xeeY\x8be5\x12\x18\xdc~g\x07x\xadR\x95\xbb\xec\xd7\xcd\x94\x91\xa6)\xa4gq\xce\xee\x9a\x1e<UL\xd6\xc6\xe7\x08\x97\x97F\xd1$P\xde\xbc\x15\xb5\xbeZjZ\xf9\xb6C \xbad\xf0'
        b'\xb4\xac\xa7*1H&\xf6\xc0\x88\xf6\xb9\xc3\xfclAyf\xfe\xf7x\t\xa1;k8\xf0\xe1\x04\xf3_\xd9\xce\xee\xef\xd5f\xc29\x8d>7\xc4\x80\xf4\x9b\x0f6n\x84m\xd4\x02d\xedPP{^;\xb1\x16\x00P'
        b'T\xac\xd8\xfc\xb66\x04\xfd\xe0\xdb\xc4\x03M\xf2(=\xc8\xe8\r\xf9\x1cj\xb2J\xc33\xd7\xd7q*\xd7N\xe3m\xc0\xa0\xed\xb5\xcc\x1d\xb5*c\xfa\xdd\x11\xa21\xc9\xa0(\xf7\xd1/t\x97\xc6)\xbb\x07\x9d\x0e\x07\xea'
        b'M\xab\xe4\xe9\x1e\x8dE\xe2\x9by7\xab\xa0\xe8\x7f\xb4\xed\xe8\xc1\xd8i<j\xdd4\xfb\x10\xb6\xcd\xa2\xb6!\xe4\x0c\xdf]\xb5\xbaz\xdd\x13c\x04\xa8a\x14RC\xdb\x9aG\xffG\x86\x84\x1f-\x1bLY\x81w\xd6V'
        b"X!7L\xc7\xabm3\xa1\xf6\n$\xe6\x03'W\x03\xb69\x82\xda\x90<\xd8\x08\x90\xfaV\xcf~\xe3{\xf8H\xafT\xbci\x0c\xc44\xad\x80X\xbc\xa3E\x0b\x08hC\x994>\xf3\xe1\xc2\xaa\x00F\xb21oQ"
        b'Y2-\xd5Y \xf2\xbd\xb5\xdc\xf6\xfb\xa9\xfe\xc5\x1e0\x93!c\xa6/\x1d\x83\x1f\x87\x169\xb8\x90\x1e\xbeZ\xe6\xc5\xfa\x89(d\xf5rx|\x12W\x966\xab\x9a\xe5\x80\x88Z\x04\x1f\x02y-\xaa\x04\x858\x8fV'
        b'\xa8\x04.\x94\xbb\xe7Hm"\x87KMZ\x1e\xf8\x1b\r\xd5\xd0\x0b\x85T/\x99U:\xcc\xffP*\x8a\xc1G\xe8{\xce\xf3\xb8\x89\xa1b\xa3\xcd1\xc8\xb2\xd6+\xe8\t\xf8&*o[\x17\xd9>beXU|\xea'
        b'\x10\xc4\xca\xb9\xa6)\xcd\xab\xfc\xb8Vo|\x9a\xd2Wx\xe5Au\x89\xb3\xf6\x91\xed\xc2\x88*r\x0e}\x85!J\x19%\x8a\xfc\x88\xad\xb5N\xb1\x96\xae\xe7?\xd6\xb4\x1eR.>=\xf7\x14\x92V\x8eu6\xb00\x1b'
        b'\x8d \x89\xea\xc4<Xj\xe4\x91\n\x91\xa8e\x14\x9d3^\x99M3\xa7.\xa9\xaa$\xfa\xc4\x95\xa6&\xae\xe9\xe7(\xff\x96\xac\xa1\xca\xad\xdf9\x91V\xd4\xb8{\xe44\xc4\xf2+\xd8\xd8\x1b\\p \x81\x1bS\xb3\xa3'
        b"!\xb8/a\x06\x12Mb\x9a\xf04\x05\xb4\x96j\x1c/\xb3\xdd\xeb\x04\x8e\xba\x90U\x87'\xff\xd0\x81\x82\x05\x9dYG\xd8r\xfd\x1b\xf2$a\x84\xd7\xd9\xb6\x1d\xd1\xd7\xf4h\xa4\xde\x0b\xd1\xbfV\xab\x07\x17[1c\x83"
        b'\xdf?\xd5\xa3\x82\xe6\xa3r\x96T\xe6\xc3\xc6\xf6EAu\x89W\xbd\xc8\x10\xf9\xa9\xf3\xbf\x01\xddu)\xc6\xcf\xcb4\xdd\x96M\xd7\xcd\xf6\x08\x9c\xaa\xf8s\xb9\x1a\xbd-\xec\x8f\xf5l\t>\xfbn\x13\xbaX\xac\xf5ut'
        b"'\x86@d\x1es\xba\xf2j\xee\x98\x0f\xd4-\x86\xa8\xbbf\x82\xb56\x06q\xcf\xe0Llz-|}\x1b\xc1*7\xd4\xc0\x01\xfa\xe5\xfdE\xdf|\xdf\xd8\x9a\xe6\x8b\xec\x99e\xddey\xa9\xc2\xfe\xeb\xf1\n\x88\xeb/"
        b"\x8d\x9f\x7f\x8a\xbb\x19\x83\xc04\xf9\x10\xe1O\xb0\xca\xd6b'TXn\xeb\xbd\xb5UT\x9ai\x82\xcc\x8c\x83\xed\xc1\x16 \xd0\x82t~\x89j\xf9\x80\x18\xf8c\xbbU\xc1\x7f7\xdd\xd4\x0c\xb8/\x03\x8e\xe6\x06d\x10\x17"
        b'\xf1\x18}\xed\x953\\3\xd6\xb2\x15gF\xa2\x1a\x7f\xb3Y\xabHZg\x81\xa8\x08It\xe2Q9\x05\x08\x99\xc5@\xf2\x97\xfc\x17Q\xcd\xe8N|\xc5\x0c{7\x07\x99Ty\xaeT\xd9k\x03\xb5\xe4p\x08\xbda\xef'
        b'\xa6\xb6\xab;\x15\xfbX~\xb5\x98\x01R\xf3#\xf8x\xc1\xce\xd1B\xc1G\xe6\xb7\xa7\xcd-=\xfe\x82\xd1u\x18\x84-Z\x1dp\x1a\xae\xe52\x87\xdd\xde\xf1?J\x97\xbf38\xdd"\x06k\xf3cvl\xb0\x85\x0b\x14'
        b'\x8a\x8e\xcb\xb6\xa9\x12\x91\xde\x08\x05\x1f\x03\xdd\x9c\xfcm"\x0b\xda\xd9\xd2Y\x0e\xd5\xa2\xb1\x046\x85\xa41\xf9\xabM\x96\xd2\xb8p\x8b\x96\xe4\x9c\x9dP&\xdc[X7\xf8\x8d\x91\x80(\xa2\xa5\xe9\xc0\x02y\x1b\x98\x81\xc8'
        b'a\x1cq\x11W8\x8a\xc5\x15\x134ps\x12\x03\xa6\xc5/0.\xa5\x9e\x93\xfc\xa3\xb2F\xb4\xb9\x92\x80\x1f\xc0Y\xb9\xb5\xb7\xcb5\xbe\x93\xc5>\xd0\x11\xff\x0f#\xb2\x86\xa7\xc4\x93p\xc4\xc84\xde\xcc\xb7l\x8ai\x9d'
        b'Fx)\xf1\xb6\x84\xce\x1ef4>\x9c\x90\x9a\x00#\x9e\xe1\xeb\xce8\xbd\x89\xfa\x0e\x00\x94\xa1\xfc\x9ck\x9b\xd4\x0e>\xb5?\xfdl\x0e\\\xdb\xe2\x1e\xa3\xb6\xc8t\xa6\x88\xb7\xe1S\xab\r\xe6\x1e\xb3\x0c7\xaa\x8dB\xa9'
        b"\xd5T\x8eRC\x98J\xb8gn\xe9\xf1d<H\x99\xcd\xcb\x07\x15\xe1\x05*\rr,g\xb8\xf2\x85\xbc\x10p'\xcc=Y_\x80s;r\xbd\x19\xef8~y(\\\xb7g\x0c\xbe\x9b\xcf\xf8\xcd'M\xc1\x12`\xc0"
        b'\xad&#\x13\x94\xf1\x17\x8f\xcc\xfd\xb2>\xbe\x83\t\xd3n:\xf6\xadv\x14x5y$\x11\xd7\xca\xf3\x93\xe8\xa9]_\xf4\xa6}t}\x92\xa4\xb6\x04^\x89\xe1\x7f\xf0r\x9d\x8f\x1cj\xa2\x83\xf11\xe0\xb0\x0c\x89vj'
        b'\x9f*{\x03\xa8<]\xddt\xcb\xa0\xd0{%~%\x7fW\xc7\xfd=\xaeQ8\xcd\x8dS\xdbNr\\a\xd9oB(,\xb5eB\xac=\xea\xc4\r\x1dN\x99\xc9\xcc\x03\x945\x85\xb0\xb5\xdbh\x03\xf3\xd0\xa0\n\xc5'
        b':\xfe\xee\xd6\xe7\x8e\x97\xa3\rJ\x0fb\xe1\xd8:|\xcc\x12\xc8\x9c\xb0\xcb\xa8\xca\xfc\x1b\xfb\x8f\x82K\xdd`\xf2\xb1\xb3z,o/\xf0\xc8m\x99\x14\xa0\xe5n\xf9f5eG\x17\xcfC\x8e\xe2\xbcKF\x9eC\xb4J'
        b"S\xcf\xadO\xd7\xae\xb3\xc1\xd5)\xdc0\xc6\xc4\xf4\xfeX\xbd\xa0\xca\x8a\x1f\x0c\\\xf2\xa4\xe1P<j\xa1\xa7\x93.\x17\x80\xd6\x06\xe6>\xab\x9e\xdc\x9ci\x12\xd49\x8c\xf36w9m')\x88\xf2\xf7\x1cr\x97*\xc1"
        b'\xd0\n\xb95]\x8a_\xea$\xc97\xd2\r\x08\xf3\x05U\xadD\xd6\xef\x9ds&\xaf\x0e\xbf\x04~8h\xf9\xb99\xaa\xde\xbar\xcb\xd7un7\xe0:\x00\xc3\x9c\xff\xa1\x10KI\xcb\x1b\x87\xff\xf8\xe4\xd0I]C\t'
        b'\xd92\x94gn\xaa\x91\xbda\x9b\x05U\xaevqz\xdc\xac\xf0l<\n}]\xd5_\xcdt\xfd\x9f\xde\xba\x98\xdf\x01\xc03\xf6\xb8u\xa9\x1d\x0e<\x12\x9e\xeb\x1fp\xa76 \xbcyP:\xf58\xc5P&F\xde\x7f'
        b't\xf1\xc9D\xf6\xc2\xbe#\xbfC\xdc\x99\xb6o\x13\x96*&<\xcb9\xfb\x96|ob\x8aY\x9aap\xddBt?\xa8\x0c*Q \xf3.\x18z:\x0c\x04\x95\xac\x04\x1e\n\xb3Uy\xe0\xbf\xec\xacG.9I\xb2'
        b'JH\x86\x19\xd2\x99\xe7\xe1\x17\xc4\x137\x08\xab\x0b\xe8\xc6\xe867\x910\x90l\xcf\x87\xec\xc7~i=\xe3\xc4\xc9\xddB\x0b3\xfc\xef3\xd6\xea\x8a\x84_\xe0\xb4\xccu\xf0\x05\xdf\x90\xc8\xf0\xb0\xe9J=z\x05\x17\xbf'
        b'\xfb\xcc\xc1\x8b\xcc\xa9\r\x01I\x8f\\\xbcn\xc2/\xff\x18 \xea7=\xb9H\x82D\xaf\x9c\xb2\x94\x18t\xbe\x8fL\xc3\x0f?\xe9,\xc4\xef\xbd\xdc\xf6?\xfe\xf7e\n\x1e\xaf\xe2\xf4\xee JM>\x00\x80\xc6@\xc7\x85'
        b'\x02\x86W\xb2j\x1e\x03\x83\x17\x1852\x90Q\x0f\x1a\xec\xa1!T\xe9\x9a\x80\x19\t(\xdd?V\xf9\xe8^}\xa8\x8cT\xecZ\xbc(\x82\x83`\x7f\x89\xe4\xe5\x86\x0fa\xa5\x1fFT\x8cs>$\x0e;e_\xa1\xd6'
        b'\x9d\xf2\x81\x16\xa6-\xba7\xaat\xc5z[Q\xa0\x06\x84\xe9#\x93\x86\x19\xcd\xf6p\xaf\x9c\xbd\x03\xf5u[f\xd02\xdc\x1a<L\xb36\x14\xe3[\xc4BKw;\xd2\x95I@\xfcqV_\xdd\x83X\xa1\x85,\x04'
        b'y.\x07\xa8\xb6\xed\x05\xd2\xa1\xa7\xfb\x0eSE\xce;Z\xda\xbd\xd8I\xad\xb1\xbe\xa5\xca\xd9\x8a\xc3\x9b\xfe|\x80\x97\xa4\xa3`&{\xebo\xcd\xdf`/\xc3_\x10j<\x1b\xc8\xe220\xbeA\x12>\xab\x0b>\x9b\xc3'
        b'\xc7\xd9A\x07\\\x9f\x8f\xcb\xa8\xd4C\xecT\xb8\xf5L\xac@ed\xd2\xd1"F,\xea)K\x144\x8b\xbc\xb0J\x92\x10\x1f\x94 \x96\xb9\x0e\x94\r\xde\x86\xa1\xac>\x08\xa6\xf13\xd9\x8b*\xed\x19\xa8\x17lz=U'
        b'MJ6AM6\xbe\x87t\xa2\xdfe\xce\x86\xb11\xde~\xef\xc5c%(Y;\xfb\xbf\x7f\xa2^k\xe3\xae\x9a\xa01JW\x1d\xdc44z\xb3Z\x88\xc2\xe3\x92TF\x9b\x1d\xe0\xe2\xe0\xc7\x9a\x8e\xebb\x81\xc8\xd5'
        b'\x8f|\x9a1\xde_7\x00\x11f\xded\xee\xeeQ \x1ao\x85c\xc6]}b\xb0\xf2\x9eLi\xcc;\x03H\xe7\x8f^"\xf0Uq\xd8\xb6\x00O\xa8\\\xc3qW\x9b\xe4"\x9e3lp#k\xbc\xb5\xfcb"\xe9'
        b'\x94\xc2\xfbYM\x93uB\xd5\xd7\xcci)LJ\x9b\xaf\xba7\xca\x91L:\xd9\xc7\xa3B\xe4z\xf5d\x10\xd8+\xac\xb4\xac\x81\x0e\xec\x10,\x81\x08~\xf2\xf9\x1e\x7f-O\\u&\xff\xce\x8azvm\xde\xf7\x8b_'
        b"\x8f8!\xb7 k3'}\xfe\xa4\xdc\x03\xd62\x0f\xf62N0n\x07\xe4\xdcr\xb5\xa4\x95\xf2\xceu\x07H\x0f\xba\xc5\xc2\t\xe7\xf7N c\xd6K\xdb\xe9\x18\r%{/\xfdb,\x08\xfa\xb6\x9e \xa3\xd3\xb0\xc9"
        b'\x85B\x82\xd0\xdb\x99|\xf0-Z\xd9\x8cbuF:\xa5#\\N>\xa1\xab\xd4/\xdc\x1c\xa6o\na\x7f\x078\x8a%hEO5\x9f9*\xaev\xd1r}\x15\x19\xd8\xdcu\xcb\x80\x08\x83r\xc7B\xd6\xdc\x938'
        b'\xe0\xd4\xec\xfa\xd6A\x14?A\xba\xf8\x83\xbe\xb4o\xfbc\x198\xc1\x19p\xa7\xdf4\xc7Z0@\xd5\t\x91\x0f\xfay\x9b\xd0\xc4Sx%k\xc9\x1fq&\x07\xa9\xb0h-\xaeD\xbeY\x08\x96dI\xdc\x9b;\x11\x88'
        b".I=j\x1c~\xba_\x9a\xd2\x91k\x95\x08\xe2!\xa0\xaf\xaa0S-\xb4S\xcd\x07S\x0e\xec*\xdd\xb4\xd0\x95\xa9'\xbd|\xd3\x80\x90\xa2\x95F\x16\xa9\x16|\xc5q\x94R\x82\xc1\xcf\xcb\x0b\xfb\xe9\x94\x0f]\xbb\xc6"
        b'\xf2\x13\xc4\xdf\xa5\xf2\x8c\xa9\xfa~\xfb\x7f\xce\x99,\xe1\x86H1\x19\x86*4\x1a$\xbe\x82a\x15\x80\x83\x7f\x018QI\xef\xd8\x9f\xa9\x84XZ~-\xeb<\xdcq\x9c\x7f\x11\xde\xb1\x86\x1f\xb6\xb3\r\xe9Z\xd4\t\xde'
        b'\xa3\xd2lr\x83\xd8\x82\x05|\xa1\x92?5\x80X\x8c\xea\x85\xf8\x04\xe4X7\x8c]\xb5C\xda\x03\xa1\xa6\xac\x8a\x92\xc0E\x84Ho\xbb\x9f\xb7\x1bZ\xf5\x11\xc8N~X`+d\x0fV\x80\x9f@\xa9\xdcO\x8a\x81\x1d'
        b'0d%\xc7\x80<\xa3\xe4\xcda\x95\xfe=\xfb\xa1\xe6\xad`4\xa1\x85\xdb\xa9\x91\xa9\xab\xa8\x08\xc5\xea\xd4\xf4k2Tw\xee\x9f\xf0\x1ccHkD$\xfe\x01$\xce\x12n\n\x98\xa6(\x0b\xb54\x80\xad\x9a!W\xf5'
        b'\xd8\xd5\xf4>*B$\x9dh)\x89rH\xb0.\xd6s\xa3\xe6z\xb7\xe2iP\xfc\xda\\\x9e\x9a\xabi\xdb\xbb\xef%B[\xa2\xc0p\xc8\xd46\xdeSV\x91\xd8\xa6H>y\x8c \xe4\xac\x16\x8b\xbcj\xb3\x99\xb4%'
        b'\x1f\xfb\x7f\xc5\xf5\xdf\xd8\xa7\xfe\xf2#\xcd6s\x94c6\xba\xab!x 33L{\xb8\xde{Da\x18\x8c\xb1K\xb5p\\\xf1\x1f\xf3\x81M\x15\x8e\x8f5y\x9d#T\x82\xcb~\x90V9;\xb0t^\x03J\xb9'
        b'J\xdf\x97\r\xcb^\x9d\xd3i\xd6\xc779\x95\x8dS\x1f"!\xb6j\xfd\xdb1\x08\xe9\xacm\x139\x0f\xae\xa1s\xf7\xefW:\xed=\xe6\xae\xbf\xf7Ei)\xa6V\xb1II+F\xb5\xee\x0b\xd51\xc0}\xb9\x99\x92'
        b'c\xddpp\xe5"\xa4w\xbbc!v\xa1\x97do\x9a\x17\xc1g\xdd\xeb2-\x83\x12qM\xa4\x15\xef\x07aI=\x07+\xdf\x08}4W\xd6\xd2p#\x97\x9c\xfc\x98\xa5/\x86m\x9a\xa6\xfa\xce\x9a\xf7\xe3\xab\xba\x16'
        b'P\x1c\xd33\xe4\xd7\xcb\xa4\x1b{\xd9\x9ap\xf9\xa2\xdf\xec\x15\xf4\x0f\xf3^\xf0\xe6\xce\xec\x00\x84M\xfa\x1dC\xee"\x9c\xa8\x17|\xe2\x15\x19\x12\xcd,\x82]A1``\xdb"\xe6j\x96p\x9d\xba7\xd6r\'\x82\x92'
        b'+N\xed\x10\xda\x86V\xf5-\xe3\x9cU\x86\x07\xf94\xbb\xec\xa8$\x19\x91t\xb2b\x85\x17\xd8\xe8\xd9L\xc5\x16\x1bd\x08\x02\x06.1\x96\xe1e\xcd\x1b\xf4\x01%/,\xdb\xa5\xdc\x0e\xb3\xe0\r\x84\x16\xd0\xf6\x01\n\x02'
        b'y\x19Ctf\xd5\x87\x9e\xa4t\x92T{p1\xe3\xed\xb6\x1b\xf6u\xd0\x0bH\xb9\xcb\xbe\x9c\x87\xd7\xf8\xcf\xd3\x004Z~9\xd4Z\xea\xaf\xfc/H\x99\xc9\x17\xb8\xbf\xcf\x01\xce\xcb\xde\x971/\x03\xeb\x13\xff\xa4\xc9'
        b'\x9f]\xa7\xf5\x8c\x99_+\xcdv->\x17bY\x1a\xe3\xdf<\xf8\xf71\xa1\x0c\x94\x93\x9d\xa1\x05\\\x8c\xd0\x1ah\x1e\x1a\xa9\xfd\xf4\xcd\x1e\x97Q1U,-\x81\x7f\xd3\x8a&\xb1\xb0\xe3\x19\xa0\xe5`\x0cC\xbd\xff\xda'
        b'\x8a\x15?\xf6a\xd3y\x8771\xf2\xab?\x1fP\x05~)\xd1\x10\xe1\xcam8?\x8f\xaf\x08\xb4(\x94\x8e\x1crVR\x97\x9b#\x06\xbb\xbd\xc78\xa8\x87\xf1\x83%U^9i\xe7\xa0\x17.\xe4%\xa7\xfe5\xa2\xe4'
        b'\xe4\xdfY\xba\xca\x0f\xc9>\xc6\xdf5\x8f\x13\x13\x07+\xbd\xeeWe.0p">\xb4\x92\x07IA\x13S&bQ\xa9L\xf9\xed\xc0\x9eN\xa5<;3\xe6gA\x11\x01_\xcar\x1c\x1cn\x85\xfa\xa4G\x9bC\x17'
        b'r\xbb\x8a\xff\x9ft\x97\xcf\xc8\x16\x10\x0b\x8d\x98r*\xaf\xafv\xbb\xf4\xf9i~+\n\xcf\xc8\x82;\x94\x86\xc88Z\x13\x0eN\x7f\xc6\x19\x94\x998t\xa34\x96\xe0O.\xaf\x90\x994\x0c\x10\x15\x15\xc8\xd6\xbfz\x87'
        b'\x9b\xf0\xe4\xc7\xaaY\xfd\xafIF\x1f2\x1c\x7f\xa2\x9fX\xfeP\xb1\x05l\xe7\x00)\xb5\xd6\x90\xa0@\x1c\xa9V{\x0eH\x13\xc3\x91\x9dV}\x89l\xca\x97l\x14\xb7\x11O\xb9b\xa7cp\x0c\t\xf9O\r\x9d(%'
        b'\xfb\x8by\xe6o\xfb\xd2sy\xc5\xc2\x03\xceFY\xd8\xe2$%\xcb.\x8e\xea\xf9\x8c\xe17\xb2}\x1f\xde2?\x98\x06`\xa2\x8a\x92\xa2\xceD~o\xdf%\xc1\xddU&\xf7\xee\x9ft\x9eH\x91t,\x16\xa6\x0b\xc7N'
        b'7+\x83\x1f\x83\x19y\xb1\x99\x9a6\x90\xb9\xb2K|\xd5\x9b0\x1f!\xdc\xdc\xa1l\xe5kQD\xc3\x93S\x91\xda\xad:cg\x8cZJ\xb0\xf5VJ.\xd2\x17\x97^\xe2\xc8\x11-\xb4\xc1\xd7\xa6\xfcBI@1"'
        b'\xec*\x17\xef\xaf\xd2\x06\x1d7\x04j\x89Y]\xeb\xaf\x9cv\x07\xbfN\x08\xd9\xd1xs\xe1\xc2}W1\x14J\t\x8atQ\x16\xa0S\x944\xfa\x93\xaf\xd7d &[m4G\xfc\x07>\x03\xd9\xde(\xac\xe9\xa7\x10'
        b'\xe3\xf1#k\n\x1f\xe7\xff\xaa\x89\x0e\x06w>[\xe8\xaa\xc3\xbd\t\xe8EH\x18\x19h\xec7\xc0\xe9f\xe4\x10\xa0\x87\x10z\x80\x99\x08\x80JD\x98\x86\xa6\xfe\xbe\xafX\xbe\xb7\xceVPS\xb7\xb3\x07\xc5\xc45\x98\xd1'
        b'x\x1d\x15\xa8\xe6\x1d\x000\xe9"\xb4\xd7\x022y<\xce\xadU\x84)\x13\x93\xda\xd8\x99\xcd\x81\xe3P\x11,$R\x00\xa4d\xe5\xea\x8d\xd7\x97\xeb\xb5\xf4\xb5\x10\xe8\xea\x8f\xf0\x01\x91\xad\x02\xd2lFO?R\xe9\xd4\x12'
        b'\xebl\xbcgRh0\x87\xa8\xc0y\x08\xe9\r\x15\r\xb7\x12\xac\x93~]\xd9\x0eKdZ\xf5\x0b\x14\x95J\xe3_~>\x9b\x03\xfb(\xd5\xd5/\xea\x85,?M) <6\x0e\x94_\xfe\xc8\xab\xca\xab\x90\xce\xf7k'
        b'\xff\xe5\xc4\x08\x127H7\xa5p\x94\x0b\x91H\xc9\xa9=?\xa6I\xdc\xdb\xc2\xe66+\x92\x107\xe8\xfe\xd2W\x04\x10\x98\xd47\x9c\x1f\xb0b\x19%\xb6/\x8e\xcb\x99"\xbc`\x03g\xcel\xce\xc6}j\x859~\x9a'
        b'\xdc \x01\x8bY\xcd\x0c\x06\xd4\x8f\x02f^\xce\xcd\x89u\xc6f\xf3\xfa}N\xa28F\xf9)`|\x18~\x05\xddgi\x97\xca]\xcb\x95\xa5\xa3\x01e\xa8\xa0\xaf\xcd\x0bF\x1b\x10\xf3\xb4\xa6\xb0;\xae\xa6\x8d\x1es1'
        b'.\xd8\xc6\xf5\xd59K\xfa\x0e\xbf(sn\xa2x\xf0\x02>\x87#\xc3%+\xddXU\xba\x10\x83V\r\x19y\x12\x87\xbe\x8d\x80KS\n\x88\xc0x\xe5\xd3\xf3\x95-\n\xb7\xc6\xa9\xac5\xbb\x96\x90\xe2\x05m\x1d<\x1b'
        b'\xacf\x01lx\xe1s\xa2\xe2\xbc\x01`\x8f\x1b\xb2\x9f\xadw\x8c\x80p\x00\xd1ie*\x8c4\x86\x7f\x82$\x91kZ\t\x02\x06\x05\x13\x9d\x99\xa9s\x1b\xe0\xb5*\x1cY\xa5a\x1aZ\xc3\xd7!23l\x12\xb6\xf8\xbe'
        b')\xbc\x96$\xe56\xd2\xa6\x99\x86?\x15Uy\n\xf9\xe1\xa8\xef\x93/\xdb\xb7\xdc&\xf3\xccY\x96\xe4\x18f[\xa1;\xc2\xa5\x10\xc4\x08/h\xcf\xddg\xf3(i\xed\xb1\xc2\xac\xc9\xfd\xa9\xde\xefF\xd7\x11\xee\xf8\x8b\x15'
        b'\x95\x1a\xef\x8e\xe8\xd2\xc1\x89")\x83?\xd0\xc1\x92]wO\xfe\x07\xcb\xd5\xb0\xf1\'\x14/\xbcp\xe0\x17\xbd\xd2\xdb\x82~2\x06}\x93fg\x90\xa7`Ma\xa3\'pv\xf0\xdd\xed0\xc1E?\x96<\x94\x9f\xebd'
        b'\xfd\xb1\x1fc!6\x86C\x8e\xb0\x15\x81\xe3\xfe\xecm\xe9z^\xf5\x89\x87M\xbb5&\xd7\xc07\xd45\x0b\xaf\xfc\x862\xe5\xd5\xd3\xf4\xf2\xb3\xa83\xfd=\x91\x08KY\xa7\xe7A\r\xbc\xa9\x8c\xf2f\xb2{\xf9\x8e\x9d'
        b'\xfe\xa7{\x9f\x84WK\xfd\x84\x12\xab\x90\x03Ms\xad\xd5K\xde\xb4\xe0\x17\xf2\xf1\xa3\xb1\xea\xea8)_\x83\x88\xbfG\xb6kIQ\x18\x91\xfe0\xca^\xe1\x03q\xed\xf1\xaazQ;Y"\xf52\xd5J\xf0\xb3\xad\xfa'
        b"9\x11EUY\xe5X\xf8\xc1\xfd$\xf6\x0b\xfb`tt\xd8\xa8t\xb7\x0c\x1fp1\x19\x9c'\xe8IJ\x98\xd1'\x1d #\x1a\xe4\xa6\xc0\xa4\x8d9\xe1`.!-\x1f\x97q\t\x91<|\x0f\xb8\x06\xcb}\xf3\xfay"
        b'\xce-\xcf\x9d?\x07\xff\x918\xcb\xaf\xc0q+%<6L\xf54i\xfb\x1b\xe1Yo\x05\xd2q\x03n:Y\xd3\x98\xd6_2\x01\x84\xcf\xd9\x8d\x82;\xf9\x18\x85\x18\x9c1\xc2?\xfc\xd4\xd1\x8b\xf4Ijg\xa7z#'
        b'iJ\xdf}\xd3.\xee\xea\xf3l\x15\x1f?\xbasl\x9b\xa0n\xf5\xf1\xeb\xd7\x8c\xc3\x18\xaa\x98\x1c\x99\x13`\x81q \xcc?r!\xf9w\xda\xa5`\xb0@\xb3\x8e\x18\x98\x96\xb0\x8e\xd2\x89[\x17\xf1\r\xa1\x07Nz\xb0'
        b"\x9c<\x1d\xfa\xc7\xd0eW\xfa'\xb2\xa1\x1d\x8ed\xe2\xb4\x15:pV\x0c\xdd\xa6\xf8+\t\xf9\x18\xb4\xdc\xcd\x8e\x1c\xabFR\x03\xd0\xbd\x005]\x14N02]\xe4vU\xc9\x1eV8\xc4\xb2\x191\xa2\xbd+\xc7Z"
        b'\xb8Rc\xf7\x8c\xe3i\x9e\\q\xc2\x00\xf3\x01\xba\xd6l%4n\x8b\xe0\x0c\xb7\xc2\xac\xca?\xf1\xdcU=F!f\xac\x02\xc9\xa41\xc5\x8d\xdb\x9f\xb9cd\xcd\xbd]\xffS\xff_\xea\xf7\x02\x0e\xe4\x1a\xf2\xba\x0e@'
        b'\xc7S\xaf\x86wh\xc2\xc4O[\x84\x10\x96\x7f,\xaat\xb8\x00G;\x81\xf5\x95U\xe46\x80^\xb8\xb9\x07\xcc\xf6\xd3\xdc\xbd\xe2\xd4\xfa\x9cA\xc8o\xf8MH\xee\x80e\x95\xa0\xbd!0u, za\x9c\\\x96@'
        b'4\xc5_\xf0\x7fN\x87\xdf)\xc0\x91\xbc\xb0-MF\xfaIs`M*\xefI\xc8\xa4\xd7\xd3: \xc9C\xd0^\xc5\xf8/\xba<]|)6V\r\x08E\x7f\xde\x07\x1e\xa0(U;y\xac\x9ezn\xd2\x18m\xb9'
        b'\x81\xfa\xed;\xfa\x10\x96\xa5J\xe4\xf5\xfb\x82!\x9a\xce\xe4\xc9\xfb\xe2\xa3\x05\xec@\xc4b\xe40\xd9\x1e\xf2\x1d\xbb\xb4&n\x8a(\xba\x85`b\xde\x97\xcf\xe2\x8cU\x90\x94n\xfe\xbd\xcc\xd0N\xa6\xdc\x14a[\xb4\xac\xda'
        b'\xbd\xa0H\xe6\x04=\x82\x86\xff\xc2\xb4(\xf3\xf5o\xf0\x05g\xa5!\xbc<\x1cvF#\xee\x9dh\xa4\xe5C{9WQ\xc2\x979\xd2\x1c4\\\xe9\x06\x17K\xa8\xb4B\xd4\x93\x84\x88\x1ep\xfe \x8c\xb8up"0'
        b'<\x9e\xd4\x84.\xf1_\xc49\xdb\xdc`{\xed\xff\x9a\xb0\xd9\x1e\xaa\x91\xc1s\xb7\x9d/\xae\x06\xb3\xb6\xb3\x04\xc8d\xb3I\xd3X\xcf\xa5\x99\r_5\xabL;\x9d\xad\xad<\xe5Gt\xb9K\xdeU\x00 ,R5\xfa'
        b'(\xbeJ\xd6\x14\xbe\xfe\xb8\x15\x05.z&\xaa\xe7\xf8\x18rXW\xde\x1e\x88b\xd1\xb2\x1e\xb4R\xe8\xe5X\xa3\xb3%\xc6\xe8\x96\x1b}\x18\xeef\xee\x91?\xeb~\xb3\x97\xaaqu\x0e^_\xa7\xe8a\x16\x14T {'
        b'\xef\xc6\xea\x0f~\xf1\xd3\xd1\x041\nH/\xe6\xaaO\xb3\x00\x96\xe0g\x8b\xf0\xb6\x06N\x127\xc8\xdeB\x7f,\xd3\x10\xa1\x7f\xd2\x87\x014\x8f\xcd\x9d\xa8\xae\xfb>\x8f\xad\xca\xcc7\xff\xc3\x9d8O\x1a\xf8\x85*i\xf8'
        b'1\x91M\xf50\x06o.\xcb|\xc6\xb2\xe7SJ\xe3\xc6|\x94\\\xfe\xe2\x949\x14\x89\xa35\x97\x04\xa9%\x13*\x96\xb0\x024\xa3:!\x87\x03&Z\xc1\x90\xe9\x15\xed\xe2\xcf\xdbP^\xee\xbd\xab\n!\xbd\xfe\x06\\'
        b"\x17\xddo\xc1\xf7\xa1\xad@\xd2\x15\x1a\xa4o\x9a\x0b'y\xc3\x00Xb\xd8\x1d\xea\x10\xd5\x836_\xd7]\xd5\x1eg\x05n\xfe\x10Ku\xddc\xcf\x07Lt\xe0\xa8\xe3\xf5\x8d\xe1e\x02\xd2\xf7\xd6\\FV\x14\xa5\x8a\xdc"
        b'\xb8\xcc\xaexZ\xdc\x19\xb4\x06\x06h^w\x8d_\xbc;2\xe0\x11\x04+\x8d@\xea\xd7H[\x05\x13\x8b\xc1p\xa7\xc0$\x07k\xc6?\xe9A\xe6\x11U\xb3s\xa7\x8c\xb2J}V\x12\xc1AEq\xbb\\9\xda\xf1\xb3'
        b'Gz\x11;m&/\x1a"\xc4.\xcb0O\xc5\x91T\xc5\x9f\xf9\xb1b\xa5\xfa\x87\xec\x0e\xe3_\xa3\xd9IR\x94*\xa4\x7f$z\xba\x1d{y\x17\xcfQp\xc6\xbea\xfe8\xd7\xf7\xe8j\xdb\n\xbfw\xc1EB\x8d'
        b"\xa9\xe5\xc0T_?\x92\x0e\xd9\xd5\x7f\x9cB\xeb9Y\xdbR\xa5\x084/Z\xd3\xf3\x8a\xe2\xc6\xd2!p\xa4\x84\xcf\x8e(\x95\xd3Y\xb5\xe6yz\x95Gn\xfa\xc2\xdb\xc1\xd1k'\xad\xf3\xd91\xe9\xfe\x8bl\xc8\xe6\xe4"
        b'\xd8\xbb\x80E\x83\xab\xeeI~\x1d%\x81\xcf\x9e|\x93\x1d-3\xa4\x90Lv\x17\x99\x88\xa8m,["A\xb8\x1f\x1dTT\x84wQ\xdf7Ry\xdc\x18!\x87\\\xe6\x10\xd8~h\xe0\xdd\xf6\x16\x96tw\x803\xdb'
        b"\x9bs%\xd6\xe9\x7f\x95k\xfbc\xde/\xb8'\x82`\xec\xcd(\njS\xcd4\xea8\nK\xa6u\xaa\x89a+3\x06g\x9aW\xc2\x8a\xbeh\xd5&>o\x89?\xe4\xfc\xderH\xea~\x9e\x8b\xee\xab$M\xa6\xe9"
        b'\xcfi\x1b7|\xf8\x80\xfa\xdbr\x90\xdd^j\x04v\x9b\x16C7\x0f\x854c\xe2\x85\x8a\xf9\xd9C8\xfa\xc3\x1d\x14\x87l\x86P\xe4\t\x01\xdf\n\xdeH\xa6\xb3\xbfhk@A/\xf1\xff\x86\x11B[0;s\xb5'
        b'\x0fdC\x91m \xf7\x8an\x82u\x9f\xce\xf2Tx\x1fK\t\xa2\x94|"\t\x01\x87\xce\xd4\xdd\xa5\x1d\xbe\xdb1\x91>\xeaT\xe6\x11}\x98\x8b)[\xd4\xb8\xf9\xf3}\xf5\xa4n\xdeW\xfb\x10\xca\x07V\xac\x97\xd6^'
        b'8\xabf8\x1eq\xf94\x8d\xd6\xb5\xa4F\xbc\x0e\xe5\xe5\xecp\x80\x80\x92&\x82r_-\xee\x9f\xec\xbf\x96\xc4\x1e\xd6]\xb97=\xf3\xc0r\xe4\xa8\xda:\xc6*\x8c\x98\xd5\xf5\xb4\xb5\x9cm\x9eq\xcaBP\xe9\x01\x00'
        b'\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00'
        b'\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
